@@ -3,5 +3,7 @@ from .iid_std_uniform import IIDStdUniform
 from .custom_iid_distribution import CustomIIDDistribution
 from .lattice import Lattice
 from .sobol import Sobol
+from .halton import Halton
+from .korobov import Korobov
 from .inverse_cdf_sampling import InverseCDFSampling
 from .acceptance_rejection_sampling import AcceptanceRejectionSampling
