@@ -1,9 +1,20 @@
 from ._discrete_distribution import DiscreteDistribution
-
+from numpy import random
 
 class CustomIIDDistribution(DiscreteDistribution):
+    """
+    Custom IID Discrte Distribution.
 
-    parameters = []
+    >>> random.seed(7)
+    >>> cd = CustomIIDDistribution(lambda n: random.poisson(lam=5,size=(n,3)))
+    >>> cd
+    CustomIIDDistribution (DiscreteDistribution Object)
+        dimension       None
+    >>> cd.gen_samples(2)
+    array([[6, 3, 3],
+           [4, 6, 6]])
+    """
+    parameters = ['dimension']
 
     def __init__(self, custom_generator):
         """
@@ -14,7 +25,8 @@ class CustomIIDDistribution(DiscreteDistribution):
         self.distrib_type = 'iid'
         self.mimics = 'Custom'
         self.dimension = None
-        super().__init__()
+        self.low_discrepancy = False
+        super(CustomIIDDistribution,self).__init__()
 
     def gen_samples(self, n):
         """
