@@ -3,7 +3,26 @@ from numpy import random
 
 
 class IIDStdGaussian(DiscreteDistribution):
+    """
+    A wrapper around NumPy's IID Standard Gaussian generator `numpy.random.randn`. 
 
+    >>> dd = IIDStdGaussian(dimension=2,seed=7)
+    >>> dd
+    IIDStdGaussian (DiscreteDistribution Object)
+        dimension       2^(1)
+        seed            7
+        mimics          StdGaussian
+    >>> dd.gen_samples(4)
+    array([[ 1.691e+00, -4.659e-01],
+           [ 3.282e-02,  4.075e-01],
+           [-7.889e-01,  2.066e-03],
+           [-8.904e-04, -1.755e+00]])
+    >>> dd.set_dimension(3)
+    >>> x = dd.gen_samples(5)
+    >>> x.shape
+    (5, 3)
+    """
+    
     parameters = ['dimension', 'seed', 'mimics']
 
     def __init__(self, dimension=1, seed=None):
@@ -16,7 +35,8 @@ class IIDStdGaussian(DiscreteDistribution):
         self.seed = seed
         random.seed(self.seed)
         self.mimics = 'StdGaussian'
-        super().__init__()
+        self.low_discrepancy = False
+        super(IIDStdGaussian,self).__init__()
 
     def gen_samples(self, n):
         """
