@@ -3,6 +3,25 @@ from numpy import random
 
 
 class IIDStdUniform(DiscreteDistribution):
+    """
+    A wrapper around NumPy's IID Standard Uniform generator `numpy.random.rand`.
+
+    >>> dd = IIDStdUniform(dimension=2,seed=7)
+    >>> dd
+    IIDStdUniform (DiscreteDistribution Object)
+        dimension       2^(1)
+        seed            7
+        mimics          StdUniform
+    >>> dd.gen_samples(4)
+    array([[0.076, 0.78 ],
+           [0.438, 0.723],
+           [0.978, 0.538],
+           [0.501, 0.072]])
+    >>> dd.set_dimension(3)
+    >>> x = dd.gen_samples(5)
+    >>> x.shape
+    (5, 3)
+    """
 
     parameters = ['dimension','seed','mimics']
 
@@ -16,7 +35,8 @@ class IIDStdUniform(DiscreteDistribution):
         self.seed = seed
         random.seed(self.seed)
         self.mimics = 'StdUniform'
-        super().__init__()
+        self.low_discrepancy = False
+        super(IIDStdUniform,self).__init__()
 
     def gen_samples(self, n):
         """
